Cost-effectiveness decision tree using recursive approach for more than 2 child nodes
Source:R/dectree_expected_recursive2.R
dectree_expected_recursive2.RdCost-effectiveness decision tree using recursive approach for more than 2 child nodes
See also
CEdecisiontree
Other CEdecisiontree:
dectree_expected_recursive()